@@ -2,7 +2,7 @@ package RapidApp;
 use strict;
 use warnings;
 
-our $VERSION = '0.99310';
+our $VERSION = '0.99311';
 
 # ABSTRACT: Turnkey ajaxy webapps
 
@@ -57,18 +57,63 @@ See L<www.rapidapp.info|http://www.rapidapp.info> and L<RapidApp::Manual> for mo
   # Start the test server (default login admin/pass):
   MyApp/script/myapp_server.pl
 
-
-
 =head1 DESCRIPTION
 
-This is the main class for the RapidApp web framework. RapidApp is an
-extension to L<Catalyst> which provides an extended development stack as well as access
-to common out-of-the-box application paradigms, such as a powerful CRUD
-front-end for L<DBIx::Class> models.
+RapidApp is an extension to L<Catalyst> - the Perl-based MVC framework. It provides a feature-rich
+extended development stack, as well as easy access to common out-of-the-box application paradigms, 
+such as powerful CRUD-based front-ends for L<DBIx::Class> models, user access and authorization, 
+RESTful URL navigation schemes, pure Ajax interfaces with no browser page loads, templating engine 
+with front-side CMS features, declarative configuration layers, and more...
 
-More documentation TBD.
+RapidApp is useful not only for new application development, but also for adding admin interfaces to 
+existing Catalyst applications, as well as for rapid prototyping.
 
-See the RapidApp website for more infomation and demos: L<http://www.rapidapp.info>
+RapidApp started as an internal project in 2009 and has been under continuous development
+ever since. It has been used very successfully for multiple medium to large-scale client 
+applications (backends with hundreds of tables and tens of millions of rows) as well as 
+many quick and easy apps and interfaces for smaller jobs.
+
+We started open-sourcing RapidApp in 2013, and this work is ongoing...
+
+RapidApp is built on top of a number of powerful open-source tools and technologies including:
+
+=over
+
+=item *
+
+Perl
+
+=item *
+
+L<Catalyst>
+
+=item *
+
+L<DBIx::Class>
+
+=item *
+
+L<ExtJS|http://www.sencha.com>
+
+=item *
+
+L<Template::Toolkit>
+
+=back
+
+Documentation is still a work-in-progress. Much of it has been done, but much of it still
+remains to be done: L<RapidApp::Manual>. 
+
+Also, be sure to check out the RapidApp website for more information, including several 
+comprehensive video demos and tutorials:
+
+=over
+
+=item *
+
+L<www.rapidapp.info|http://www.rapidapp.info>
+
+=back
 
 =head1 AUTHOR
 
